@@ -1,4 +1,4 @@
-# $Id: NodeList.pm,v 1.3 2002/09/14 20:49:33 phish Exp $
+# $Id: NodeList.pm,v 1.4 2002/11/08 09:47:32 phish Exp $
 
 package XML::LibXML::NodeList;
 use strict;
@@ -104,6 +104,7 @@ sub iterator {
 package XML::LibXML::NodeList::Iterator;
 
 use strict;
+use XML::NodeFilter qw(:results);
 
 use overload
   '++' => sub { $_[0]->next;     $_[0]; },
@@ -126,14 +127,60 @@ sub new {
     if ( defined $list ) {
         $self = bless [
                        $list,
-                       0
+                       0,
+                       [],
                       ], $class;
     }
+
     return $self;
 }
 
-sub first    { $_[0][1]=0; return $_[0][0][0]; }
-sub last     { $_[0][1]=scalar(@{$_[0][0]})-1; return $_[0][0][-1]; }
+sub set_filter {
+    my $self = shift;
+    $self->[2] = [ @_ ];
+}
+
+sub add_filter {
+    my $self = shift;
+    push @{$self->[2]}, @_;
+}
+
+# helper function.
+sub accept_node {
+    foreach ( @{$_[0][2]} ) {
+        my $r = $_->accept_node($_[1]);
+        return $r if $r;
+    }
+    # no filters or all decline ...
+    return FILTER_ACCEPT;
+}
+
+sub first    { $_[0][1]=0;
+               my $s = scalar(@{$_[0][0]});
+               while ( $_[0][1] < $s ) {
+                   last if $_[0]->accept_node($_[0][0][$_[0][1]]) == FILTER_ACCEPT;
+                   $_[0][1]++;
+               }
+               return undef if $_[0][1] == $s;
+               return $_[0][0][$_[0][1]]; }
+
+sub last     {
+    my $i = scalar(@{$_[0][0]})-1;
+    while($i >= 0){
+        if ( $_[0]->accept_node($_[0][0][$i] == FILTER_ACCEPT) ) {
+            $_[0][1] = $i;
+            last;
+        }
+        $i--;
+    }
+
+    if ( $i < 0 ) {
+        # this costs a lot, but is more safe
+        return $_[0]->first;
+    }
+    return $_[0][0][$i];
+}
+
 sub current  { return $_[0][0][$_[0][1]]; }
 sub index    { return $_[0][1]; }
 
@@ -141,7 +188,15 @@ sub next     {
     if ( (scalar @{$_[0][0]}) <= ($_[0][1] + 1)) {
         return undef;
     }
-    $_[0][1]++;
+    my $i = $_[0][1];
+    while ( 1 ) {
+        $i++;
+        return undef if $i >= scalar @{$_[0][0]};
+        if ( $_[0]->accept_node( $_[0][0]->[$i] ) == FILTER_ACCEPT ) {
+            $_[0][1] = $i;
+            last;
+        }
+    }
     return $_[0][0]->[$_[0][1]];
 }
 
@@ -149,7 +204,15 @@ sub previous {
     if ( $_[0][1] <= 0 ) {
         return undef;
     }
-    $_[0][1]--;
+    my $i = $_[0][1];
+    while ( 1 ) {
+        $i--;
+        return undef if $i < 0;
+        if ( $_[0]->accept_node( $_[0][0]->[$i] ) == FILTER_ACCEPT ) {
+            $_[0][1] = $i;
+            last;
+        }
+    }
     return $_[0][0][$_[0][1]];
 }
 
